raytraverse.evaluate
==========================================================

BaseMetricSet
---------------------------------

.. autoclass:: raytraverse.evaluate.BaseMetricSet
    :members:
    :undoc-members:
    :show-inheritance:

MultiLumMetricSet
---------------------------------

.. autoclass:: raytraverse.evaluate.MultiLumMetricSet
    :members:
    :undoc-members:
    :show-inheritance:

MetricSet
---------------------------------

.. autoclass:: raytraverse.evaluate.MetricSet
    :members:
    :undoc-members:
    :show-inheritance:

FieldMetric
---------------------------------

.. autoclass:: raytraverse.evaluate.FieldMetric
    :members:
    :undoc-members:
    :show-inheritance:

SamplingMetrics
---------------------------------

.. autoclass:: raytraverse.evaluate.SamplingMetrics
    :members:
    :undoc-members:
    :show-inheritance:

PositionIndex
---------------------------------

.. autoclass:: raytraverse.evaluate.PositionIndex
    :members:
    :undoc-members:
    :show-inheritance:

retina
-------

.. automodule:: raytraverse.evaluate.retina
    :members:
    :undoc-members:
    :show-inheritance:
